pub struct EmbedderSection {
pub model: String,
}Expand description
v0.8: embedding-model selection. model is one of the curated
built-in ids exposed by kimetsu brain model list
(bge-small-en-v1.5, bge-m3, jina-v2-base-code). Switching
changes the vector dimension, so a kimetsu brain reindex is
required for cosine retrieval to use the new model.
Fields
model: StringTrait Implementations
Sourceimpl Clone for EmbedderSection
impl Clone for EmbedderSection
Sourcefn clone(&self) -> EmbedderSection
fn clone(&self) -> EmbedderSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmbedderSection
impl Debug for EmbedderSection
Sourceimpl Default for EmbedderSection
impl Default for EmbedderSection
Sourceimpl<'de> Deserialize<'de> for EmbedderSection
impl<'de> Deserialize<'de> for EmbedderSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more